@@ -29,7 +29,7 @@ checkInputGenerateDCS <- function(cdm,
 
   errorMessage <- checkmate::makeAssertCollection()
   checkmate::expect_character(name, len = 1)
-  checkmate::expect_date(cohortDateRange, len = 2, null.ok = TRUE)
+  checkmate::expect_date(cohortDateRange, len = 2)
   checkmate::assert_list(ageGroup,
     add = errorMessage
   )
